<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Http\Requests;
use App\Http\Controllers\Controller;
use App\Layer;
use App\Slider;
use App\AboutSetting;
use App\HomeSetting;
use App\News;
use App\Image;
use App\Alshuyukh;
use App\Reward;
use App\Certification;
use App\Category;
use App\Media;
use App\Service;

class FrontController extends Controller {

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index() {

        $sliders = Slider::orderBy('order', 'ASC')->get();
        $about = AboutSetting::where('key', 'life_brief')->first()->value;
        $news = News::orderBy('created_at', 'desc')->limit(5)->get();
        $apps = HomeSetting::where('key', 'app')->get();
        $animate = ['fadeInLeft', 'fadeInUp', 'fadeInDown', 'fadeInUpBig', 'fadeInDownBig', 'fadeIn', 'bounceIn', 'bounceInDown'];
        $images = Image::orderByRaw("RAND()")->limit(8)->get();
        foreach ($sliders as $k => $slide) {
            $layers['main' . $slide->id] = Layer::where('slide_id', $slide->id)->orderBy('order', 'ASC')->get();
        }
        return view('front.index', compact('sliders', 'layers', 'about', 'apps', 'news', 'animate', 'images'));
    }

    public function about() {
        $about = AboutSetting::lists('value', 'key');
        $alshuyukh = Alshuyukh::all();
        $rewards = Reward::all();
        $certifications = Certification::all();
        $anashed = Media::where('category_id', '8')->select('title')->get();
        $khatmat = Media::where('category_id', '3')->get();
        return view('front.about', compact('about', 'alshuyukh', 'rewards', 'certifications', 'anashed', 'khatmat'));
    }

    public function librarywork() {
        return view('front.librarywork.librarywork');
    }

    public function news() {
        $news = News::all();
        return view('front.news.list', compact('news'));
    }

    public function showNews($id) {
        $news = News::findOrFail($id);
        return view('front.news.inner', compact('news'));
    }

    public function album() {
        $images = Image::orderBy('order', 'ASC')->get();
        $animate = ['fadeInLeft', 'fadeInUp', 'fadeInDown', 'fadeInUpBig', 'fadeInDownBig', 'fadeIn', 'bounceIn', 'bounceInDown'];
        return view('front.images', compact('images', 'animate'));
    }

    public function baqat() {
        $services = Service::all();
        return view('front.baqat', compact('services'));
    }

    public function contact_us() {
        return view('front.contact-us');
    }

    public function videos() {
        $type = 2;
        $title = "فيديوهات";
        $category = menuCategory($type);
        return view('front.librarywork.media', compact('type', 'title', 'category'));
    }

    public function audios() {
        $type = 1;
        $title = "الصوتيـات";
        $category = menuCategory($type);
        return view('front.librarywork.media', compact('type', 'title', 'category'));
    }

    public function libraryMedia($id) {
        $cat = Category::where('id', $id)->first();
        $title = $cat->title;
        $type = $cat->type;
        $category = Category::where('parent_id', $id)->get();

        if (count($category) <= 0) {
            $media = Media::where('category_id', $id)->get();
            if ($type == 2){
                 $media = Media::where('category_id', $id)->limit(settings('video_per_page'))->get();
                 $count = Media::where('category_id', $id)->count();
                return view('front.librarywork.video', compact('title', 'media', 'id', 'cat','count'));
            }
            elseif ($type == 1 && count($media) > 1) {
                $id = Category::where('id', $id)->first()->parent_id;
                return view('front.librarywork.inner_audio', compact('title', 'media', 'id'));
            } elseif ($type == 1 && count($media) == 1) {
                $media = $media[0];
                $title = $media->title;
                return view('front.librarywork.audio', compact('title', 'media', 'id'));
            }
        }
        return view('front.librarywork.inner_media', compact('title', 'category', 'type', 'id'));
    }

    public function playMedia($id) {
        $media = Media::where('id', $id)->first();
        $title = $media->title;
        $id = Category::where('id', $media->category_id)->first()->parent_id;

        return view('front.librarywork.audio', compact('title', 'media', 'id'));
    }

    public function baqat_alerts($id) {

        $service = Service::findOrFail($id);
        return view('front.afasy_alerts', compact('service'));
    }

    public function get_alert() {

        $id = $_GET['id'];

        $url = 'http://ivas.com.eg/cms/API/ACommand?CPID=1&OpID=' . $id;

        $json = file_get_contents($url);

        echo $json;
    }

    public function get_rpts() {
        $id = $_GET['id'];
        $url = 'http://ivas.com.eg/cms/API/RBTs?CPID=1&Paginate=1200&OpID=' . $id;
        $json = file_get_contents($url);
        $data = json_decode($json);
        $results = array();
        $data = $data->data;
        foreach ($data as $v) {
            $results[] = array(
                "rbt_name" => $v->title,
                "rbt_path" => $v->path,
                "rbt_id" => $v->id,
                "from_sms" => $v->SMSCode,
                "to_rbtsms" => $v->operator->RBTSMS
            );
        }
        echo json_encode($results);
    }

    static function baqat_info() {

        function ip_info($ip = NULL, $purpose = "location", $deep_detect = TRUE) {
            $output = NULL;
            if (filter_var($ip, FILTER_VALIDATE_IP) === FALSE) {
                $ip = $_SERVER["REMOTE_ADDR"];
                if ($deep_detect) {
                    if (filter_var(@$_SERVER['HTTP_X_FORWARDED_FOR'], FILTER_VALIDATE_IP))
                        $ip = $_SERVER['HTTP_X_FORWARDED_FOR'];
                    if (filter_var(@$_SERVER['HTTP_CLIENT_IP'], FILTER_VALIDATE_IP))
                        $ip = $_SERVER['HTTP_CLIENT_IP'];
                }
            }
            $purpose = str_replace(array("name", "\n", "\t", " ", "-", "_"), NULL, strtolower(trim($purpose)));
            $support = array("country", "countrycode", "state", "region", "city", "location", "address");
            $continents = array(
                "AF" => "Africa",
                "AN" => "Antarctica",
                "AS" => "Asia",
                "EU" => "Europe",
                "OC" => "Australia (Oceania)",
                "NA" => "North America",
                "SA" => "South America"
            );
            if (filter_var($ip, FILTER_VALIDATE_IP) && in_array($purpose, $support)) {
                $ipdat = @json_decode(file_get_contents("http://www.geoplugin.net/json.gp?ip=" . $ip));
                if (@strlen(trim($ipdat->geoplugin_countryCode)) == 2) {
                    switch ($purpose) {
                        case "location":
                            $output = array(
                                "city" => @$ipdat->geoplugin_city,
                                "state" => @$ipdat->geoplugin_regionName,
                                "country" => @$ipdat->geoplugin_countryName,
                                "country_code" => @$ipdat->geoplugin_countryCode,
                                "continent" => @$continents[strtoupper($ipdat->geoplugin_continentCode)],
                                "continent_code" => @$ipdat->geoplugin_continentCode
                            );
                            break;
                        case "address":
                            $address = array($ipdat->geoplugin_countryName);
                            if (@strlen($ipdat->geoplugin_regionName) >= 1)
                                $address[] = $ipdat->geoplugin_regionName;
                            if (@strlen($ipdat->geoplugin_city) >= 1)
                                $address[] = $ipdat->geoplugin_city;
                            $output = implode(", ", array_reverse($address));
                            break;
                        case "city":
                            $output = @$ipdat->geoplugin_city;
                            break;
                        case "state":
                            $output = @$ipdat->geoplugin_regionName;
                            break;
                        case "region":
                            $output = @$ipdat->geoplugin_regionName;
                            break;
                        case "country":
                            $output = @$ipdat->geoplugin_countryName;
                            break;
                        case "countrycode":
                            $output = @$ipdat->geoplugin_countryCode;
                            break;
                    }
                }
            }
            return $output;
        }

        $detected_country = ip_info("Visitor", "Country");

//echo $detected_country;

        $arr = array();
        $json = file_get_contents('http://ivas.com.eg/cms/API/Ops');
        $data_op = json_decode($json);

        $countries = array();
        $coun = "";
        foreach ($data_op as $d) {
            array_push($countries, $d->country->Name);
        }
        foreach ($countries as $c) {
            if ($c == $detected_country) {
                $coun = $c;
            }
        }

        if ($coun != $detected_country) {
            echo "<p class='rbt_p'>عفوا لا يوجد شركات اتصال في الوقت الحالي</p>";
        } else {
            echo "<h2 class='op_title'>برجاء اختيـار شبكتك</h2>";
            $count = 0;
            foreach ($data_op as $d) {
                if ($d->country->Name == $detected_country && $d->Name != "Free") {
                    ?>
                    <a class="opclass" id="<?php echo $d->id; ?>" style="cursor: pointer" hre='#'>
                        <img width="125"src='http://ivas.com.eg/cms/<?php echo $d->Logo; ?>'></a>&nbsp;&nbsp;
                    <?php
                    if ($count == 1) {
                        echo '<br/>';
                        $count = 0;
                    }
                }
                $count++;
            }
        }
    }

    public function loadMoreVideos($id) {
        $media = Media::where('category_id', $id)->paginate(settings('video_per_page'));       
        $view = view('front.librarywork.load', compact('media'))->render();
        return Response(array('html' => $view, 'count' => $media->lastPage()));
    }

}
