<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Http\Requests;
use App\Http\Controllers\Controller;
use Validator;
use App\News;

class NewsController extends Controller {

    public function __construct() {
        if (!file_exists('uploads/news')) {
            mkdir('uploads/news', 0777, true);
        }
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index() {
        $news = News::all();
        return view('news.index', compact('news'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create(Request $request) {


        $news = NULL;

        return view('news.form', compact('news'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request) {
        $validator = Validator::make($request->all(), [
                    'title' => 'required|unique:news,title',
                    'image' => 'required',
        ]);
        if ($validator->fails()) {
            return back()->withErrors($validator)->withInput();
        }
        $news = new News($request->all());
        $file = $request->file('image');
        $path = $this->destinationFolder . "news/";
        $uniqueID = time();
        $file->move($path, $uniqueID . "." . $file->getClientOriginalExtension());
        $news->image = $path . $uniqueID . "." . $file->getClientOriginalExtension();
        $file2 = $request->file('inner_image');
        $path = $this->destinationFolder . "news/";
        $uniqueID = time();
        $file2->move($path, $uniqueID . "." . $file2->getClientOriginalExtension());
        $news->inner_image = $path . $uniqueID . "." . $file2->getClientOriginalExtension();
        $news->save();
        $request->session()->flash('success', 'News Created Successfully');
        return redirect('news');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id) {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id) {

        $news = News::findOrFail($id);

        return view('news.form', compact('news'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id) {
        $validator = Validator::make($request->all(), [
                    'title' => 'required|unique:news,title,' . $id,
        ]);
        if ($validator->fails()) {
            return back()->withErrors($validator);
        }
        $oldNews = News::findOrFail($id);
        $news = $request->all();

        if ($request->hasFile('image')) {
            $file = $request->file('image');
            $path = $this->destinationFolder . "news/";
            $uniqueID = time();
            $file->move($path, $uniqueID . "." . $file->getClientOriginalExtension());
            $news['image'] = $path . $uniqueID . "." . $file->getClientOriginalExtension();
            $this->delete_image_if_exists($oldNews->image);
        }
        if ($request->hasFile('inner_image')) {
            $file2 = $request->file('inner_image');
            $path = $this->destinationFolder . "news/";
            $uniqueID = time();
            $file2->move($path, $uniqueID . "." . $file2->getClientOriginalExtension());
            $news['inner_image'] = $path . $uniqueID . "." . $file2->getClientOriginalExtension();
            $this->delete_image_if_exists($oldNews->inner_image);
        }

        $oldNews->update($news);
        \Session::flash('success', 'News Updated Successfully');
        return redirect('news');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id) {
        $news = News::findOrFail($id);
        $news->delete();
        $this->delete_image_if_exists($news->image);
        $this->delete_image_if_exists($news->inner_image);
        \Session::flash('success', 'News Deleted Successfully');
        return redirect('news');
    }

}
